pub struct AccessPoint { /* private fields */ }
A wireless access point.

This is obtained from WirelessDevice’s methods.

Implementations

source

impl AccessPoint

source

pub async fn capability_flags( &self ) -> Result<AccessPointCapabilityFlags, Error>

Flags describing the capabilities of the access point.

source

pub async fn wpa_security_flags( &self ) -> Result<AccessPointSecurityFlags, Error>

Flags describing the access point’s capabilities according to WPA (Wifi Protected Access).

source

pub async fn rsn_security_flags( &self ) -> Result<AccessPointSecurityFlags, Error>

Flags describing the access point’s capabilities according to RSN (Robust Secure Network).

source

pub async fn ssid(&self) -> Result<Vec<u8>, Error>

The access point’s SSID (Service Set IDentifier).

This is the raw octets, not a human-readable string. Generally, you’ll be able to read this as a UTF-8 string, but it is not guaranteed.

May be empty if the access point has a hidden SSID, and can be up to 32 bytes long.

source

pub async fn frequency(&self) -> Result<u32, Error>

The radio channel frequency in use by the access point, in MHz.

source

pub async fn bssid(&self) -> Result<String, Error>

The hardware address (BSSID) of the access point.

source

pub async fn mode(&self) -> Result<AccessPointMode, Error>

The operating mode of the access point.

source

pub async fn max_bitrate(&self) -> Result<u32, Error>

The maximum bitrate this access point is capable of, in kilobits/second (Kb/s).

source

pub async fn strength(&self) -> Result<u8, Error>

The current signal quality of the access point, in percent.

source

pub async fn last_seen(&self) -> Result<Option<u32>, Error>

The timestamp for the last time the access point was found in scan results.

This is in CLOCK_BOOTTIME seconds.

A value of None means the access point has never been found in scan results.