Struct passcod_networkmanager::device::wireless::WirelessDevice
source · pub struct WirelessDevice { /* private fields */ }Expand description
A Wi-Fi device.
Implementations
sourceimpl WirelessDevice
impl WirelessDevice
sourcepub async fn get_all_access_points(
&self
) -> Result<impl Iterator<Item = AccessPoint> + '_, Error>
pub async fn get_all_access_points( &self ) -> Result<impl Iterator<Item = AccessPoint> + '_, Error>
Get the list of all access points visible to this device.
This includes “hidden” access points, for which the SSID is not yet known.
sourcepub async fn request_scan(&self) -> Result<(), Error>
pub async fn request_scan(&self) -> Result<(), Error>
Request a new scan for access points.
sourceimpl WirelessDevice
impl WirelessDevice
sourcepub async fn permanent_hardware_address(&self) -> Result<String, Error>
pub async fn permanent_hardware_address(&self) -> Result<String, Error>
The permanent hardware address of the device.
sourcepub async fn mode(&self) -> Result<WirelessClientMode, Error>
pub async fn mode(&self) -> Result<WirelessClientMode, Error>
The operating mode of the wireless device.
sourcepub async fn bitrate(&self) -> Result<u32, Error>
pub async fn bitrate(&self) -> Result<u32, Error>
The current bit rate used by the device, in kilobits/second.
sourcepub async fn access_points(
&self
) -> Result<impl Iterator<Item = AccessPoint> + '_, Error>
pub async fn access_points( &self ) -> Result<impl Iterator<Item = AccessPoint> + '_, Error>
The list of access points visible to this device.
sourcepub async fn active_access_point(&self) -> Result<Option<AccessPoint>, Error>
pub async fn active_access_point(&self) -> Result<Option<AccessPoint>, Error>
The access point currently used by the wireless device.
sourcepub async fn capabilities(&self) -> Result<WirelessClientCapabilityFlags, Error>
pub async fn capabilities(&self) -> Result<WirelessClientCapabilityFlags, Error>
The capabilities of the wireless device.