pub struct NetworkManager { /* private fields */ }

Implementations

source

impl NetworkManager

source

pub async fn new() -> Result<Self, Error>

Create a new NetworkManager instance.

source

pub fn new_with_zbus(zbus: Connection) -> Self

Create a new NetworkManager instance with a custom D-Bus connection.

source

pub async fn reload(&self, flags: ReloadFlags) -> Result<(), Error>

Reload NetworkManager.

source

pub async fn get_devices( &self ) -> Result<impl Iterator<Item = Device> + '_, Error>

Get the list of realized network devices.

Returns the network devices known to the system. Does not include device placeholders (see get_all_devices()).

source

pub async fn get_all_devices( &self ) -> Result<impl Iterator<Item = Device> + '_, Error>

Get the list of all network devices.

Includes device placeholders (eg, devices that do not yet exist but which could be automatically created by NetworkManager if one of their AvailableConnections was activated).

source

pub async fn get_device_by_ip_interface_name( &self, iface: &str ) -> Result<Device, Error>

Get the network device referenced by its IP interface name.

Note that some devices (usually modems) only have an IP interface name when they are connected.

source

pub async fn enable(&self, enabled: bool) -> Result<(), Error>

source

pub async fn is_networking_enabled(&self) -> Result<bool, Error>

source

pub async fn is_wireless_enabled(&self) -> Result<bool, Error>

source

pub async fn is_wireless_hardware_enabled(&self) -> Result<bool, Error>

source

pub async fn is_wimax_enabled(&self) -> Result<bool, Error>

source

pub async fn is_wimax_hardware_enabled(&self) -> Result<bool, Error>

source

pub async fn is_wwan_enabled(&self) -> Result<bool, Error>

source

pub async fn is_wwan_hardware_enabled(&self) -> Result<bool, Error>

source

pub async fn is_connectivity_check_enabled(&self) -> Result<bool, Error>

source

pub async fn is_starting_up(&self) -> Result<bool, Error>

Indicates whether NetworkManager is still starting up.

This becomes false when NetworkManager has finished attempting to activate every connection that it might be able to activate at startup.

source

pub fn settings(&self) -> Settings

Settings service object