pub struct Settings { /* private fields */ }
Connection Settings Profile Manager.

Implementations

source

impl Settings

source

pub async fn list_connections( &self ) -> Result<impl Iterator<Item = Connection> + '_, Error>

List the saved network connections known to NetworkManager.

source

pub async fn get_connection_by_uuid( &self, uuid: &str ) -> Result<Connection, Error>

Retrieve the object path of a connection, given that connection’s UUID.

source

pub async fn add_connection( &self, properties: HashMap<&str, HashMap<&str, Value<'_>>> ) -> Result<Connection, Error>

Add a new connection and save it to disk.

This operation does not start the network connection unless:

  • the device is idle and able to connect to the network described by the new connection, and
  • the connection is allowed to be started automatically.
source

pub async fn hostname(&self) -> Result<String, Error>

The machine hostname stored in persistent configuration.

source

pub async fn can_modify(&self) -> Result<bool, Error>

Whether adding and modifying connections is supported.