pub enum AccessPointMode {
Unknown = 0,
AdHoc = 1,
Infrastructure = 2,
Mesh = 4,
}Expand description
The 802.11 mode an access point can be in.
This is the same as WirelessClientMode internally to NetworkManager, but is exposed as a
different type in this API to differentiate between the two contexts it can be obtained in.
Variants
Unknown = 0
The access point mode is unknown.
AdHoc = 1
Indicates the object is part of an Ad-Hoc 802.11 network without a central coordinating access point.
Infrastructure = 2
The access point is in infrastructure mode.
This indicates the object is an access point that provides connectivity to clients.
Mesh = 4
The access point is a 802.11s mesh point.