pub enum DeviceState {
Show 13 variants Unknown = 0, Unmanaged = 10, Unavailable = 20, Disconnected = 30, Preparing = 40, Configuring = 50, NeedsAuth = 60, ConfiguringIP = 70, CheckingIP = 80, Secondaries = 90, Activated = 100, Deactivating = 110, Failed = 120,
}
The state of a network device.

Variants



Unknown = 0

The device’s state is unknown.



Unmanaged = 10

The device is recognized, but not managed by NetworkManager.



Unavailable = 20

the device is managed by NetworkManager, but is not available for use.

Reasons may include the wireless switched off, missing firmware, no ethernet carrier, missing supplicant or modem manager, etc.



Disconnected = 30

The device can be activated, but is currently idle and not connected to a network.



Preparing = 40

The device is preparing the connection to the network.

This may include operations like changing the MAC address, setting physical link properties, and anything else required to connect to the requested network.



Configuring = 50

The device is connecting to the requested network.

This may include operations like associating with the Wi-Fi AP, dialing the modem, connecting to the remote Bluetooth device, etc.



NeedsAuth = 60

The device requires more information to continue connecting to the requested network.

This includes secrets like WiFi passphrases, login passwords, PIN codes, etc.



ConfiguringIP = 70

The device is requesting IPv4 and/or IPv6 addresses and routing information from the network.



CheckingIP = 80

The device is checking whether further action is required for the requested network connection.

This may include checking whether only local network access is available, whether a captive portal is blocking access to the Internet, etc.



Secondaries = 90

The device is waiting for a secondary connection (like a VPN) which must activate before this device can be activated.



Activated = 100

The device has a network connection, either local or global.



Deactivating = 110

A disconnection from the current network connection was requested, and the device is cleaning up resources used for that connection.

The network connection may still be valid.



Failed = 120

The device failed to connect to the requested network and is cleaning up the connection request.