pub enum WirelessClientMode {
    Unknown = 0,
    AdHoc = 1,
    Station = 2,
    Hotspot = 3,
    Mesh = 4,
}
The 802.11 mode a wireless client can be in.

This is the same as AccessPointMode internally to NetworkManager, but is exposed as a different type in this API to differentiate between the two contexts it can be obtained in.

Variants



Unknown = 0

The device mode is unknown.



AdHoc = 1

Indicates the device is part of an Ad-Hoc 802.11 network without a central coordinating access point.



Station = 2

The device is in infrastructure mode.

This indicates the device is an 802.11 client/station.



Hotspot = 3

The device is a hotspot.



Mesh = 4

The device is a 802.11s mesh point.