pub struct AccessPointSecurityFlags(/* private fields */);Expand description
Flags describing Wi-Fi access point security properties.
Implementations
sourceimpl AccessPointSecurityFlags
impl AccessPointSecurityFlags
sourcepub const PAIR_WEP40: Self = _
pub const PAIR_WEP40: Self = _
40/64-bit WEP is supported for pairwise/unicast encryption.
sourcepub const PAIR_WEP104: Self = _
pub const PAIR_WEP104: Self = _
104/128-bit WEP is supported for pairwise/unicast encryption.
sourcepub const GROUP_WEP40: Self = _
pub const GROUP_WEP40: Self = _
40/64-bit WEP is supported for group/broadcast encryption.
sourcepub const GROUP_WEP104: Self = _
pub const GROUP_WEP104: Self = _
104/128-bit WEP is supported for group/broadcast encryption.
sourcepub const GROUP_TKIP: Self = _
pub const GROUP_TKIP: Self = _
TKIP is supported for group/broadcast encryption.
sourcepub const GROUP_CCMP: Self = _
pub const GROUP_CCMP: Self = _
AES/CCMP is supported for group/broadcast encryption.
sourcepub const KEY_MGMT_PSK: Self = _
pub const KEY_MGMT_PSK: Self = _
WPA/RSN Pre-Shared Key encryption is supported.
sourcepub const KEY_MGMT_802_1X: Self = _
pub const KEY_MGMT_802_1X: Self = _
WPA/RSN 802.1x authentication and key management is supported.
sourcepub const KEY_MGMT_SAE: Self = _
pub const KEY_MGMT_SAE: Self = _
WPA/RSN Simultaneous Authentication of Equals (SAE) is supported.
sourcepub const KEY_MGMT_OWE: Self = _
pub const KEY_MGMT_OWE: Self = _
Opportunistic Wireless Encryption (OWE) is supported.
sourcepub const KEY_MGMT_OWE_TM: Self = _
pub const KEY_MGMT_OWE_TM: Self = _
Opportunistic Wireless Encryption (OWE) in transition mode is supported.
sourcepub const KEY_MGMT_EAP_SUITE_B_192: Self = _
pub const KEY_MGMT_EAP_SUITE_B_192: Self = _
WPA3 Enterprise Suite-B 192 bit mode is supported.
sourceimpl AccessPointSecurityFlags
impl AccessPointSecurityFlags
sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
sourceimpl AccessPointSecurityFlags
impl AccessPointSecurityFlags
sourcepub const fn iter(&self) -> Iter<AccessPointSecurityFlags>
pub const fn iter(&self) -> Iter<AccessPointSecurityFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
sourcepub const fn iter_names(&self) -> IterNames<AccessPointSecurityFlags>
pub const fn iter_names(&self) -> IterNames<AccessPointSecurityFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.