pub struct ActivationStateFlags(/* private fields */);Expand description
Flags describing the current activation state.
Implementations
sourceimpl ActivationStateFlags
impl ActivationStateFlags
sourcepub const LAYER2_READY: Self = _
pub const LAYER2_READY: Self = _
Layer2 is activated and ready.
sourcepub const IPV4_READY: Self = _
pub const IPV4_READY: Self = _
IPv4 setting is completed.
sourcepub const IPV6_READY: Self = _
pub const IPV6_READY: Self = _
IPv6 setting is completed.
sourcepub const MASTER_HAS_SLAVES: Self = _
pub const MASTER_HAS_SLAVES: Self = _
The master has any slave devices attached.
This only makes sense if the device is a master.
sourcepub const LIFETIME_BOUND_TO_PROFILE_VISIBILITY: Self = _
pub const LIFETIME_BOUND_TO_PROFILE_VISIBILITY: Self = _
The lifetime of the activation is bound to the visibility of the connection profile,
which in turn depends on connection.permissions and whether a session for the user
exists.
sourceimpl ActivationStateFlags
impl ActivationStateFlags
sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
sourceimpl ActivationStateFlags
impl ActivationStateFlags
sourcepub const fn iter(&self) -> Iter<ActivationStateFlags>
pub const fn iter(&self) -> Iter<ActivationStateFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
sourcepub const fn iter_names(&self) -> IterNames<ActivationStateFlags>
pub const fn iter_names(&self) -> IterNames<ActivationStateFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.