Struct passcod_networkmanager::device::AppliedConnection
source · pub struct AppliedConnection {
pub settings: HashMap<String, HashMap<String, OwnedValue>>,
pub version: u64,
}Expand description
The currently applied connection on the device.
Obtained from Device::get_applied_connection().
Fields
settings: HashMap<String, HashMap<String, OwnedValue>>The effective connection settings that the connection has currently applied.
version: u64The version ID of the currently applied connection.
This can be specified during Device::reapply() to avoid races where you first fetch the
applied connection, modify it and try to reapply it. If the applied connection is
modified in the meantime, the version gets incremented and the reapply will fail.