Struct passcod_networkmanager::device::wireless::AccessPoint
source · pub struct AccessPoint { /* private fields */ }Expand description
A wireless access point.
This is obtained from WirelessDevice’s methods.
Implementations
sourceimpl AccessPoint
impl AccessPoint
sourcepub async fn capability_flags(
&self
) -> Result<AccessPointCapabilityFlags, Error>
pub async fn capability_flags( &self ) -> Result<AccessPointCapabilityFlags, Error>
Flags describing the capabilities of the access point.
sourcepub async fn wpa_security_flags(
&self
) -> Result<AccessPointSecurityFlags, Error>
pub async fn wpa_security_flags( &self ) -> Result<AccessPointSecurityFlags, Error>
Flags describing the access point’s capabilities according to WPA (Wifi Protected Access).
sourcepub async fn rsn_security_flags(
&self
) -> Result<AccessPointSecurityFlags, Error>
pub async fn rsn_security_flags( &self ) -> Result<AccessPointSecurityFlags, Error>
Flags describing the access point’s capabilities according to RSN (Robust Secure Network).
sourcepub async fn ssid(&self) -> Result<Vec<u8>, Error>
pub async fn ssid(&self) -> Result<Vec<u8>, Error>
The access point’s SSID (Service Set IDentifier).
This is the raw octets, not a human-readable string. Generally, you’ll be able to read this as a UTF-8 string, but it is not guaranteed.
May be empty if the access point has a hidden SSID, and can be up to 32 bytes long.
sourcepub async fn frequency(&self) -> Result<u32, Error>
pub async fn frequency(&self) -> Result<u32, Error>
The radio channel frequency in use by the access point, in MHz.
sourcepub async fn bssid(&self) -> Result<String, Error>
pub async fn bssid(&self) -> Result<String, Error>
The hardware address (BSSID) of the access point.
sourcepub async fn mode(&self) -> Result<AccessPointMode, Error>
pub async fn mode(&self) -> Result<AccessPointMode, Error>
The operating mode of the access point.
sourcepub async fn max_bitrate(&self) -> Result<u32, Error>
pub async fn max_bitrate(&self) -> Result<u32, Error>
The maximum bitrate this access point is capable of, in kilobits/second (Kb/s).