Struct passcod_networkmanager::Settings
source · pub struct Settings { /* private fields */ }Expand description
Connection Settings Profile Manager.
Implementations
sourceimpl Settings
impl Settings
sourcepub async fn list_connections(
&self
) -> Result<impl Iterator<Item = Connection> + '_, Error>
pub async fn list_connections( &self ) -> Result<impl Iterator<Item = Connection> + '_, Error>
List the saved network connections known to NetworkManager.
sourcepub async fn get_connection_by_uuid(
&self,
uuid: &str
) -> Result<Connection, Error>
pub async fn get_connection_by_uuid( &self, uuid: &str ) -> Result<Connection, Error>
Retrieve the object path of a connection, given that connection’s UUID.
sourcepub async fn add_connection(
&self,
properties: HashMap<&str, HashMap<&str, Value<'_>>>
) -> Result<Connection, Error>
pub async fn add_connection( &self, properties: HashMap<&str, HashMap<&str, Value<'_>>> ) -> Result<Connection, Error>
Add a new connection and save it to disk.
This operation does not start the network connection unless:
- the device is idle and able to connect to the network described by the new connection, and
- the connection is allowed to be started automatically.
sourcepub async fn hostname(&self) -> Result<String, Error>
pub async fn hostname(&self) -> Result<String, Error>
The machine hostname stored in persistent configuration.
sourcepub async fn can_modify(&self) -> Result<bool, Error>
pub async fn can_modify(&self) -> Result<bool, Error>
Whether adding and modifying connections is supported.